@@ -10,9 +10,9 @@ use Rose::DB::Object::MakeMethods::Date;
 use Rose::DB::Object::Metadata::Column;
 our @ISA = qw(Rose::DB::Object::Metadata::Column);
 
-our $VERSION = '0.04';
+our $VERSION = '0.70';
 
-__PACKAGE__->add_common_method_maker_argument_names('default', 'type');
+__PACKAGE__->add_common_method_maker_argument_names('default', 'time_zone', 'type');
 
 Rose::Object::MakeMethods::Generic->make_methods
 (
@@ -54,13 +54,18 @@ sub method_should_set
 
 sub parse_value
 {
-  shift; 
-  my $db = shift;
+  my($self, $db) = (shift, shift);
+
   my $dt = $db->parse_date(@_);
 
-  unless($dt)
+  if($dt)
   {
-    $dt = Rose::DateTime::Util::parse_date($_[0], $db->server_time_zone)
+    $dt->set_time_zone($self->time_zone || $db->server_time_zone)
+      if(UNIVERSAL::isa($dt, 'DateTime'));
+  }
+  else
+  {
+    $dt = Rose::DateTime::Util::parse_date($_[0], $self->time_zone || $db->server_time_zone)
   }
 
   return $dt;
@@ -123,7 +128,11 @@ See the L<Rose::DB::Object::Metadata::Column|Rose::DB::Object::Metadata::Column/
 
 =item B<parse_value DB, VALUE>
 
-Convert VALUE to the equivalent C<DateTime> object.  VALUE maybe returned unmodified if it is a valid date keyword or otherwise has special meaning to the underlying database.  DB is a L<Rose::DB> object that is used as part of the parsing process.  Both arguments are required.
+Convert VALUE to the equivalent L<DateTime> object.  VALUE maybe returned unmodified if it is a valid date keyword or otherwise has special meaning to the underlying database.  DB is a L<Rose::DB> object that is used as part of the parsing process.  Both arguments are required.
+
+=item B<time_zone [TZ]>
+
+Get or set the time zone of the dates stored in this column.  TZ should be a time zone name that is understood by L<DateTime::TimeZone>.
 
 =item B<type>
 
