@@ -229,6 +229,9 @@ sub build_select
       my $rel_column    =  $table_map->{$table_tn} ?
         "$table_map->{$table_tn}.$column" : '';
 
+      # Avoid duplicate clauses if the table name matches the relationship name
+      $rel_column = ''  if($rel_column eq $fq_column);
+
       my $method = $obj_meta ? $obj_meta->column_rw_method_name($column) : undef;
 
       unless($query_only_columns || !$select_columns{$column})
@@ -693,7 +696,8 @@ sub _format_value
       }
       else
       {
-        $value = $col_meta->format_value($db, $col_meta->parse_value($db, $value));
+        $value = $col_meta->format_value($db, $col_meta->parse_value($db, $value))
+          if(defined $value);
       }
     }
   }
@@ -733,7 +737,8 @@ sub _format_value
     }
     else
     {
-      $value = $col_meta->format_value($db, $col_meta->parse_value($db, $value));
+      $value = $col_meta->format_value($db, $col_meta->parse_value($db, $value))
+        if(defined $value);
     }
   }
 
